@@ -41,8 +41,10 @@ COMMAND(CLIENT_INFO, "CLIENT", "INFO", 2, NONE, 0)
 COMMAND(CLIENT_KILL, "CLIENT", "KILL", -3, NONE, 0)
 COMMAND(CLIENT_LIST, "CLIENT", "LIST", -2, NONE, 0)
 COMMAND(CLIENT_NO_EVICT, "CLIENT", "NO-EVICT", 3, NONE, 0)
+COMMAND(CLIENT_NO_TOUCH, "CLIENT", "NO-TOUCH", 3, NONE, 0)
 COMMAND(CLIENT_PAUSE, "CLIENT", "PAUSE", -3, NONE, 0)
 COMMAND(CLIENT_REPLY, "CLIENT", "REPLY", 3, NONE, 0)
+COMMAND(CLIENT_SETINFO, "CLIENT", "SETINFO", 4, NONE, 0)
 COMMAND(CLIENT_SETNAME, "CLIENT", "SETNAME", 3, NONE, 0)
 COMMAND(CLIENT_TRACKING, "CLIENT", "TRACKING", -3, NONE, 0)
 COMMAND(CLIENT_TRACKINGINFO, "CLIENT", "TRACKINGINFO", 2, NONE, 0)
@@ -98,9 +100,9 @@ COMMAND(DISCARD, "DISCARD", NULL, 1, NONE, 0)
 COMMAND(DUMP, "DUMP", NULL, 2, INDEX, 1)
 COMMAND(ECHO, "ECHO", NULL, 2, NONE, 0)
 COMMAND(EVAL, "EVAL", NULL, -3, KEYNUM, 2)
-COMMAND(EVAL_RO, "EVAL_RO", NULL, -3, KEYNUM, 2)
 COMMAND(EVALSHA, "EVALSHA", NULL, -3, KEYNUM, 2)
 COMMAND(EVALSHA_RO, "EVALSHA_RO", NULL, -3, KEYNUM, 2)
+COMMAND(EVAL_RO, "EVAL_RO", NULL, -3, KEYNUM, 2)
 COMMAND(EXEC, "EXEC", NULL, 1, NONE, 0)
 COMMAND(EXISTS, "EXISTS", NULL, -2, INDEX, 1)
 COMMAND(EXPIRE, "EXPIRE", NULL, -3, INDEX, 1)
@@ -125,9 +127,9 @@ COMMAND(GEODIST, "GEODIST", NULL, -4, INDEX, 1)
 COMMAND(GEOHASH, "GEOHASH", NULL, -2, INDEX, 1)
 COMMAND(GEOPOS, "GEOPOS", NULL, -2, INDEX, 1)
 COMMAND(GEORADIUS, "GEORADIUS", NULL, -6, INDEX, 1)
-COMMAND(GEORADIUS_RO, "GEORADIUS_RO", NULL, -6, INDEX, 1)
 COMMAND(GEORADIUSBYMEMBER, "GEORADIUSBYMEMBER", NULL, -5, INDEX, 1)
 COMMAND(GEORADIUSBYMEMBER_RO, "GEORADIUSBYMEMBER_RO", NULL, -5, INDEX, 1)
+COMMAND(GEORADIUS_RO, "GEORADIUS_RO", NULL, -6, INDEX, 1)
 COMMAND(GEOSEARCH, "GEOSEARCH", NULL, -7, INDEX, 1)
 COMMAND(GEOSEARCHSTORE, "GEOSEARCHSTORE", NULL, -8, INDEX, 1)
 COMMAND(GET, "GET", NULL, 2, INDEX, 1)
@@ -235,8 +237,8 @@ COMMAND(RENAMENX, "RENAMENX", NULL, 3, INDEX, 1)
 COMMAND(REPLCONF, "REPLCONF", NULL, -1, NONE, 0)
 COMMAND(REPLICAOF, "REPLICAOF", NULL, 3, NONE, 0)
 COMMAND(RESET, "RESET", NULL, 1, NONE, 0)
-COMMAND(RESTORE_ASKING, "RESTORE-ASKING", NULL, -4, INDEX, 1)
 COMMAND(RESTORE, "RESTORE", NULL, -4, INDEX, 1)
+COMMAND(RESTORE_ASKING, "RESTORE-ASKING", NULL, -4, INDEX, 1)
 COMMAND(ROLE, "ROLE", NULL, 1, NONE, 0)
 COMMAND(RPOP, "RPOP", NULL, -2, INDEX, 1)
 COMMAND(RPOPLPUSH, "RPOPLPUSH", NULL, 3, INDEX, 1)
@@ -256,7 +258,7 @@ COMMAND(SDIFF, "SDIFF", NULL, -2, INDEX, 1)
 COMMAND(SDIFFSTORE, "SDIFFSTORE", NULL, -3, INDEX, 1)
 COMMAND(SELECT, "SELECT", NULL, 2, NONE, 0)
 COMMAND(SENTINEL_CKQUORUM, "SENTINEL", "CKQUORUM", 3, NONE, 0)
-COMMAND(SENTINEL_CONFIG, "SENTINEL", "CONFIG", -3, NONE, 0)
+COMMAND(SENTINEL_CONFIG, "SENTINEL", "CONFIG", -4, NONE, 0)
 COMMAND(SENTINEL_DEBUG, "SENTINEL", "DEBUG", -2, NONE, 0)
 COMMAND(SENTINEL_FAILOVER, "SENTINEL", "FAILOVER", 3, NONE, 0)
 COMMAND(SENTINEL_FLUSHCONFIG, "SENTINEL", "FLUSHCONFIG", 2, NONE, 0)
@@ -318,6 +320,7 @@ COMMAND(UNLINK, "UNLINK", NULL, -2, INDEX, 1)
 COMMAND(UNSUBSCRIBE, "UNSUBSCRIBE", NULL, -1, NONE, 0)
 COMMAND(UNWATCH, "UNWATCH", NULL, 1, NONE, 0)
 COMMAND(WAIT, "WAIT", NULL, 3, NONE, 0)
+COMMAND(WAITAOF, "WAITAOF", NULL, 4, NONE, 0)
 COMMAND(WATCH, "WATCH", NULL, -2, INDEX, 1)
 COMMAND(XACK, "XACK", NULL, -4, INDEX, 1)
 COMMAND(XADD, "XADD", NULL, -5, INDEX, 1)
